@@ -56,6 +56,7 @@ impl BgpkitBroker {
     /// See [QueryParams] for the parameters you can pass in.
     pub fn query(&self, params: &QueryParams) -> Result<QueryResult, BrokerError> {
         let url = format!("{}/search{}", &self.broker_url, params);
+        log::info!("sending broker query to {}", &url);
         match reqwest::blocking::get(url) {
             Ok(res) => {
                 match res.json::<QueryResult>()
@@ -73,6 +74,43 @@ impl BgpkitBroker {
             Err(e) => { return Err(BrokerError::from(e)) }
         }
     }
+
+    /// Send query to get **all** data times returned.
+    pub fn query_all(&self, params: &QueryParams) -> Result<Vec<BrokerItem>, BrokerError> {
+        let mut p: QueryParams = params.clone();
+        let mut items = vec![];
+        loop {
+            let url = format!("{}/search{}", &self.broker_url, &p);
+            log::info!("sending broker query to {}", &url);
+            let total_page ;
+            match reqwest::blocking::get(url) {
+                Ok(res) => {
+                    match res.json::<QueryResult>()
+                    {
+                        Ok(res) => {
+                            if let Some(e) = res.error {
+                                return Err(BrokerError::BrokerError(e));
+                            } else {
+                                let data = res.data.unwrap();
+                                total_page = data.total_pages;
+                                items.extend(data.items);
+                            }
+                        },
+                        Err(e) => { return Err(BrokerError::from(e)) }
+                    }
+                }
+                Err(e) => { return Err(BrokerError::from(e)) }
+            }
+
+            let cur_page = p.page;
+            if cur_page >= total_page {
+                // reaches the end
+                break;
+            }
+            p = p.page(cur_page+1);
+        }
+        Ok(items)
+    }
 }
 
 #[cfg(test)]
@@ -113,4 +151,17 @@ mod tests {
         assert!(res.is_err());
         assert!(matches!(res.err(), Some(BrokerError::BrokerError(_))));
     }
+
+    #[test]
+    fn test_query_all() {
+        let mut params = QueryParams::new();
+        params = params.start_ts(1634693400);
+        params = params.end_ts(1634693400);
+        params = params.page_size(10);
+
+        let broker = BgpkitBroker::new("https://api.broker.bgpkit.com/v1");
+        let res = broker.query_all(&params);
+        assert!(res.is_ok());
+        assert_eq!(res.ok().unwrap().len(), 58);
+    }
 }
\ No newline at end of file
